==> flutter_windows_v0.1.5-beta.zip: flutter/.pub-cache/hosted/pub.dartlang.org/test-0.12.30+3/lib/src/runner/browser/default_settings.dart <==
// Copyright (c) 2017, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:collection';

import '../../backend/test_platform.dart';
import '../executable_settings.dart';

/// Default settings for starting browser executables.
final defaultSettings = new UnmodifiableMapView({
  TestPlatform.chrome: new ExecutableSettings(
      linuxExecutable: 'google-chrome',
      macOSExecutable:
          '/Applications/Google Chrome.app/Contents/MacOS/Google Chrome',
      windowsExecutable: r'Google\Chrome\Application\chrome.exe'),
  TestPlatform.contentShell: new ExecutableSettings(
      linuxExecutable: 'content_shell',
      macOSExecutable: 'content_shell',
      windowsExecutable: 'content_shell.exe'),
  TestPlatform.dartium: new ExecutableSettings(
      linuxExecutable: 'dartium',
      macOSExecutable: 'dartium',
      windowsExecutable: 'dartium.exe'),
  TestPlatform.firefox: new ExecutableSettings(
      linuxExecutable: 'firefox',
      macOSExecutable: '/Applications/Firefox.app/Contents/MacOS/firefox-bin',
      windowsExecutable: r'Mozilla Firefox\firefox.exe'),
  TestPlatform.internetExplorer: new ExecutableSettings(
      windowsExecutable: r'Internet Explorer\iexplore.exe'),
  TestPlatform.phantomJS: new ExecutableSettings(
      linuxExecutable: 'phantomjs',
      macOSExecutable: 'phantomjs',
      windowsExecutable: 'phantomjs.exe'),
  TestPlatform.safari: new ExecutableSettings(
      macOSExecutable: '/Applications/Safari.app/Contents/MacOS/Safari')
});

==> flutter_windows_v0.2.3-beta.zip: flutter/.pub-cache/hosted/pub.dartlang.org/test-0.12.32+1/lib/src/runner/browser/default_settings.dart <==
// Copyright (c) 2017, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:collection';

import '../../backend/runtime.dart';
import '../executable_settings.dart';

/// Default settings for starting browser executables.
final defaultSettings = new UnmodifiableMapView({
  Runtime.chrome: new ExecutableSettings(
      linuxExecutable: 'google-chrome',
      macOSExecutable:
          '/Applications/Google Chrome.app/Contents/MacOS/Google Chrome',
      windowsExecutable: r'Google\Chrome\Application\chrome.exe'),
  Runtime.contentShell: new ExecutableSettings(
      linuxExecutable: 'content_shell',
      macOSExecutable: 'content_shell',
      windowsExecutable: 'content_shell.exe'),
  Runtime.dartium: new ExecutableSettings(
      linuxExecutable: 'dartium',
      macOSExecutable: 'dartium',
      windowsExecutable: 'dartium.exe'),
  Runtime.firefox: new ExecutableSettings(
      linuxExecutable: 'firefox',
      macOSExecutable: '/Applications/Firefox.app/Contents/MacOS/firefox-bin',
      windowsExecutable: r'Mozilla Firefox\firefox.exe'),
  Runtime.internetExplorer: new ExecutableSettings(
      windowsExecutable: r'Internet Explorer\iexplore.exe'),
  Runtime.phantomJS: new ExecutableSettings(
      linuxExecutable: 'phantomjs',
      macOSExecutable: 'phantomjs',
      windowsExecutable: 'phantomjs.exe'),
  Runtime.safari: new ExecutableSettings(
      macOSExecutable: '/Applications/Safari.app/Contents/MacOS/Safari')
});
